smartcard.CardMonitoring.CardObserver

# ``smartcard`.`CardMonitoring`.`CardObserver``

class documentation

`class CardObserver(Observer):`

Known subclasses: `smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._CardObserver`

View In Hierarchy

CardObserver is a base abstract class for objects that are to be notified upon smart card insertion / removal.

Method | `__init__` | Undocumented
Method | `update` | Called upon smart card insertion / removal.

def __init__(self):
overridden in `smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._CardObserver`

Undocumented

def update(self, observable, handlers):
overrides `smartcard.Observer.Observer.update`
overridden in `smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._CardObserver`

Called upon smart card insertion / removal.

Parameters
observable |
handlers | addedcards: list of inserted smart cards causing notification removedcards: list of removed smart cards causing notification